Convert e-mails from mbox (i.e., several mails in a single box) format to eml (i.e., every mail in a single file) format.
convert_mbox_eml(mbox, dir, format = "mbox", delim = NULL)No explicit return value.
As a side product the directory dir contains the e-mails in eml
format.
a character string or connection describing the mbox location.
a character string describing the output directory.
see MBoxSource.
see MBoxSource.
Ingo Feinerer and Kurt Hornik